<?php

namespace Drp\NativeEventApp\Test\Api\Auth;

use Drp\NativeEventApp\Auth\Facades\AuthInfoFinder;
use Drp\NativeEventApp\Models\Device;
use Drp\NativeEventApp\Test\Api\GraphQLTestCase;
use Drp\NativeEventApp\Test\Support\InteractsWithAuth;
use Spatie\Snapshots\MatchesSnapshots;

class FirebaseDeviceIdTest extends GraphQLTestCase
{
    use MatchesSnapshots, InteractsWithAuth;

    /** @test */
    public function stores_firebase_device_id_for_logged_in_user(): void
    {
        $accessToken = $this->createAccessToken('accessToken');

        $query = 'mutation {
              storeFirebaseDeviceId (firebaseDeviceId: "TEST")
            }';

        $this->assertMatchesJsonSnapshot($this->graphQlRequest($query, ['Authorization' => 'Bearer ' . $accessToken]));

        $this->assertEquals('TEST', Device::all()->first()->firebase_device_id);
    }

    /** @test */
    public function removes_firebase_device_id_for_logged_in_user(): void
    {
        $accessToken = $this->createAccessToken('accessToken');
        $device = factory(Device::class)->create([
            'auth_identifier' => AuthInfoFinder::current()->getId(),
        ]);

        $query = 'mutation {
              removeFirebaseDeviceId
            }';

        $this->assertMatchesJsonSnapshot($this->graphQlRequest($query, ['Authorization' => 'Bearer ' . $accessToken]));

        $this->assertNull($device->fresh()->firebase_device_id);
    }
}
