<?php

namespace Drp\NativeEventApp\Test\Unit;

use Drp\NativeEventApp\Exceptions\FormNotFound;
use Drp\NativeEventApp\Forms\Facades\FormSubmission;
use Drp\NativeEventApp\Models\Registration;
use Drp\NativeEventApp\Test\Support\Fakes\FakeForm;
use Drp\NativeEventApp\Test\Support\Fakes\FakeFormRegistry;
use Drp\NativeEventApp\Test\TestCase;
use Nuwave\Lighthouse\Exceptions\ValidationException;
use Spatie\Snapshots\MatchesSnapshots;

class FormHandlerTest extends TestCase
{
    use MatchesSnapshots;

    /** @test */
    public function throws_a_validation_exception_on_validation_failure()
    {
        FormSubmission::handle('fake-form', FakeForm::class);

        $this->expectException(ValidationException::class);

        FormSubmission::process('fake-form', json_encode([
            'name' => 'test',
        ]), new Registration);
    }

    /** @test */
    public function throws_an_exception_if_form_not_found()
    {
        $this->expectException(FormNotFound::class);

        FormSubmission::process('fake-form', json_encode([
            'name' => 'test',
            'question' => 'test',
        ]), new Registration);
    }

    /** @test */
    public function returns_data_on_success()
    {
        FormSubmission::handle('fake-form', FakeForm::class);

        $data = FormSubmission::process('fake-form', json_encode([
            'name' => 'test',
            'question' => 'test',
        ]), new Registration);

        $this->assertEquals(200, $data['status']);
        $this->assertEquals("", $data['message']);
        $this->assertEquals("{\"name\":\"test\",\"question\":\"test\"}", $data['submissionData']);
    }
}
