<?php

namespace Drp\NativeEventApp\Test\Unit\Notifications;

use Drp\NativeEventApp\Models\Device;
use Drp\NativeEventApp\Models\Notification;
use Drp\NativeEventApp\Notifications\PushNotification;
use Drp\NativeEventApp\Notifications\PushNotificationSender;
use Drp\NativeEventApp\Test\Support\Builders\DeviceBuilder;
use Drp\NativeEventApp\Test\Support\InteractsWithEvents;
use Drp\NativeEventApp\Test\TestCase;
use Illuminate\Support\Facades\Bus;
use Illuminate\Support\Facades\Notification as NotificationFacade;

class PushNotificationSenderTest extends TestCase
{
    use InteractsWithEvents;

    /**
     * @var PushNotificationSender
     */
    protected $sender;

    /**
     * @var DeviceBuilder
     */
    protected $deviceBuilder;

    protected function setUp(): void
    {
        parent::setUp();

        $this->sender = app(PushNotificationSender::class, [
            'notification' => factory(Notification::class)->state('published')->create(),
        ]);
        $this->deviceBuilder = app(DeviceBuilder::class);

        Bus::fake();
        NotificationFacade::fake();

        $this->registerFakeEvent();
    }

    /** @test */
    public function it_can_send_a_notification_to_a_device(): void
    {
        $this->deviceBuilder
            ->create();

        $device = Device::first();

        $this->sender->toDevice($device);

        NotificationFacade::assertSentTo($device, PushNotification::class);
    }

    /** @test */
    public function it_can_send_a_notification_to_all_devices(): void
    {
        $this->deviceBuilder
            ->times(3)
            ->create();

        $this->sender->toAllDevices();

        NotificationFacade::assertTimesSent(3, PushNotification::class);
    }

    /** @test */
    public function it_wont_attempt_to_notify_if_no_firebase_device_id_set(): void
    {
        $this->deviceBuilder
            ->times(3)
            ->create();

        $devices = Device::all();
        $devices->first()->update([
            'firebase_device_id' => null,
        ]);
        $devices->last()->update([
            'firebase_device_id' => null,
        ]);

        $this->sender->toAllDevices();

        NotificationFacade::assertTimesSent(1, PushNotification::class);
    }
}
